// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2001 Liam Girdwood  


#include <gnome--/main.h>
#include <gnome--/about.h>
#include "config.h"
#include "application.hh"
#include "file_selector.hh"
#include "application.hh"
#include "observation_list_dialog.hh"
#include "observation_log_dialog.hh"
#include "observation_details_dialog.hh"
#include "ccd_capture_image_dialog.hh"
#include "new_ephemeris_druid.hh"
#include "sky_local_dialog.hh"
#include "sky_markers_dialog.hh"
#include "sky_near_dialog.hh"
#include "sky_deep_dialog.hh"
#include "virtual_sky_druid.hh"
#include "ephemeris_edit_dialog.hh"
#include "observatory_connect.hh"
#include "database_ephemeris_druid.hh"
#include "file_new_dialog.hh"
#include "nova.hh"
#include "libnova.h"
 

//manage(new class observation_log_dialog());
//manage(new class observation_details_dialog());


//
//manage(new class ephemeris_edit_dialog());
//manage(new class database_ephemeris_druid());
//manage(new class new_ephemeris_druid());


void application::on_file_new_activate()
{   
	int selection = -1;
	int result = 0;
	
	// set up dialog
	file_new_dialog * dlg = manage(new class file_new_dialog());
	dlg->set_selection_data(&selection);
	
	if (!dlg->run_and_close())
	{
		// OK selected
		switch (selection)
		{
			case 0:
			{
				// new virtual sky
				virtual_sky_druid * dlg = manage(new class virtual_sky_druid());
				virtual_sky_info * info = new virtual_sky_info();
				dlg->set_vsky_info (info);
				
				// display druid
				result = dlg->run_and_close();
				
				// did it finish ok
				if (info->is_finished())
				{
					// create page and add to mdi parent
					virtual_sky_page *page = manage(new class virtual_sky_page());
  					Gtk::Label *label = manage(new class Gtk::Label(info->get_name()));
					label->set_name(info->get_name());
   					label->set_alignment(0.5, 0.5);
					label->set_padding(0, 0);
  					m_mdi->pages().push_back(Gtk::Notebook_Helpers::TabElem(*page, *label));
					m_mdi->set_page (m_mdi->page_num(*page));
					
					// set user data for callbacks
					info->set_page (page);
					page->set_vsky_info(info);
					Gtk::Widget * child = m_mdi->get_current()->get_child();
					child->set_user_data((gpointer)page);

				}
				
			}
			break;
			case 1:
			{
				// new database ephemeris
				database_ephemeris_druid * dlg = manage(new class database_ephemeris_druid());
				dlg->run_and_close();
			}
			break;
			case 2:
			{
				// new object ephemeris
				new_ephemeris_druid * dlg = manage(new class new_ephemeris_druid());
				dlg->run_and_close();
			}
			break;
			case 3:
			{
				// new target list
				observation_list_dialog * dlg = manage(new class observation_list_dialog());
				dlg->run_and_close();

			}
			break;
			default:
			{
				// error
				Gnome::Dialogs::error("Invalid Selection");
			}
			break;
		}			
	}
}

void application::on_file_open_activate()
{   
	file_selector * dlg = manage(new class file_selector());
	dlg->run_and_close();
}


void application::on_save_activate()
{   
}

void application::on_save_as_activate()
{
	file_selector * dlg = manage(new class file_selector());
	dlg->run_and_close();   
}

void application::on_print_activate()
{   
}

void application::on_print_setup_activate()
{   
}

void application::on_file_close_activate()
{
	// check for valid page type
	Gtk::Widget * page = get_page();
	virtual_sky_page * vpage = 0;
	
	if (page)
	{
		m_mdi->pages().remove(*page);
		vpage = dynamic_cast<virtual_sky_page*>(page);
		if (vpage)
		{ 
			virtual_sky_info * info = vpage->get_vsky_info();
			delete info;
			delete vpage;
		}
		
	}   

}
void application::on_exit_activate()
{   
	// quit Nova, but check for modified data first
	Gtk::Main::quit();
}

void application::on_file_activate()
{   
}

void application::on_edit_ephemeris_activate()
{   
}

void application::on_edit_target_list_activate()
{   
}

void application::on_edit_object_activate()
{   
}

void application::on_cairneyhill1_activate()
{   
}

void application::on_window_virtual_sky_activate()
{   
}

void application::on_tlist_n2_activate()
{   
}

void application::on_window_fits_activate()
{   
}

void application::on_window_activate()
{   
}

void application::on_eph1_activate()
{   
}

void application::on_eph2_activate()
{   
}

void application::on_eph3_activate()
{   
}

void application::on_view_moon_activate()
{   
}

void application::on_mercury_activate()
{   
}

void application::on_view_venus_activate()
{   
}

void application::on_view_mars_activate()
{   
}

void application::on_view_jupiter_activate()
{   
}

void application::on_view_saturn_activate()
{   
}

void application::on_view_uranus_activate()
{   
}

void application::on_view_neptune_activate()
{   
}

void application::on_view_pluto_activate()
{   
}

void application::on_view_asteroids_activate()
{   
}

void application::on_view_comets_activate()
{   
}

void application::on_view_galaxies_activate()
{   
}

void application::on_view_nebulae_activate()
{   
}

void application::on_view_other_activate()
{   
}

void application::on_view_coordinates_activate()
{   
}

void application::on_view_search_activate()
{   
}

void application::on_view_virtual_object_activate()
{   
}

void application::on_view_zoom_to_fit_activate()
{   
}

void application::on_view_zoom_select_activate()
{   
}

void application::on_view_in_x_2_activate()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_in (2);      
}

void application::on_view_in_x_5_activate()
{  
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_in (5);    
}

void application::on_view_in_x_10_activate()
{   
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_out (10);   
}

void application::on_view_in_select_fov_activate()
{   
}

void application::on_view_out_x_0p5_activate()
{  
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_out (2);    
}

void application::on_view_ot_0p2_activate()
{   
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_out (5);   
}

void application::on_view_out_0p1x_activate()
{   
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_out (10);   
}

void application::on_view_out_select_fov_activate()
{   
}

void application::on_settings_location_activate()
{ 
	sky_local_dialog *dlg = manage(new class sky_local_dialog());
	dlg->run_and_close();
}

void application::on_view_markers_activate()
{   
	sky_markers_dialog * dlg = manage(new class sky_markers_dialog());
	dlg->run_and_close();
}

void application::on_settings_near_sky()
{   
	sky_near_dialog * dlg = manage(new class sky_near_dialog());
	dlg->run_and_close();
}

void application::on_settings_deep_sky_activate()
{   
	sky_deep_dialog * dlg = manage(new class sky_deep_dialog());
	dlg->run_and_close();
}

void application::on_observatory_connect_activate()
{   
	observatory_connect * dlg = manage(new class observatory_connect());
	dlg->run_and_close();
}

void application::on_observatory_disconnect_activate()
{   
}

void application::on_execute_target_list_activate()
{   
	observation_list_dialog * dlg = manage(new class observation_list_dialog());
	dlg->run_and_close();
}

void application::on_stop_target_list_activate()
{   
}

void application::on_dome_open_activate()
{   
}

void application::on_dome_close_activate()
{   
}

void application::on_telescope_focus_activate()
{   
}

void application::on_goto_moon_activate()
{   
}

void application::on_goto_mercury_activate()
{   
}

void application::on_goto_venus_activate()
{   
}

void application::on_goto_mars_activate()
{   
}

void application::on_goto_jupiter_activate()
{   
}

void application::on_goto_saturn_activate()
{   
}

void application::on_goto_uranus_activate()
{   
}

void application::on_goto_neptune_activate()
{   
}

void application::on_goto_pluto_activate()
{   
}

void application::on_goto_asteroid_activate()
{   
}

void application::on_goto_comet_activate()
{   
}

void application::on_goto_galaxies_activate()
{   
}

void application::on_goto_nebulae_activate()
{   
}

void application::on_goto_other_activate()
{   
}

void application::on_goto_position_activate()
{   
}

void application::on_goto_virtual_sky_coordinates_activate()
{   
}

void application::on_goto_search_activate()
{   
}

void application::on_telescope_goto_activate()
{   
}

void application::on_telescope_park_activate()
{   
}

void application::on_ccd_capture_activate()
{   
	ccd_capture_image_dialog * dlg = manage(new class ccd_capture_image_dialog());
	dlg->run_and_close();
}

void application::on_ccd_live_view_activate()
{   
}

void application::on_ccd_dark_frame_activate()
{   
}

void application::on_tools_enhance_image_activate()
{   
}

void application::on_options_database_activate()
{   
}

void application::on_help_contents_activate()
{   
}

void application::on_about_activate()
{
	//set authors
	vector <string> authors;
	authors.push_back("Liam Girdwood <liam@nova-ioe.org>");
	authors.push_back("Juan Carlos Remis Fernandez <jcremis@cajaespana.es>");
	
	//get libnova version 
	char * ln_version = get_ln_version();
	char about_other_info[256];
	strcpy (about_other_info, "Using libnova V ");
	strcat (about_other_info, ln_version);
	strcat (about_other_info, "\n\nIcons by SpunkyIndigo.com <thomas@spunkyindigo.com>");
	
	//get logo
	char logo[256];
	get_pixmap_file ("novalogo.png", logo);

	// create about
	Gnome::About * about = manage(new class Gnome::About(PACKAGE, VERSION, 
		"Copyright 2001 The Nova I.O.E. Team", authors, 
		about_other_info, logo));
		 
	about->run_and_close ();
}

void application::on_set_cylindrical_projection()
{   
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->set_cylindrical_projection();
}

void application::on_set_spherical_projection()
{   
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->set_spherical_projection();
}

void application::on_set_mag_limit_brighter()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->set_mag_limit_brighter();
}

void application::on_set_mag_limit_fainter()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->set_mag_limit_fainter();
}

void application::on_set_alt_az_coords()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->set_alt_az_coords();
}

void application::on_set_ra_dec_coords()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->set_ra_dec_coords();
}

void application::on_goto_object_button_clicked()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->goto_coords (0,0); // liam
}

void application::on_zoom_in_button_clicked()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_in  (0.1);
}

void application::on_zoom_out_button_clicked()
{
	virtual_sky_page * vpage = get_vsky_page();
	if (vpage)
		vpage->get_vsky_info()->zoom_out (0.1);   
}


// return a ptr to the current (in focus) virtual sky page
virtual_sky_page * application::get_vsky_page ()
{
	Gtk::Widget * page = get_page();
	return dynamic_cast<virtual_sky_page*>(page);
}

Gtk::Widget * application::get_page()
{
	Gtk::Notebook_Helpers::Page * page = m_mdi->get_current();
	if (page)
	{
		Gtk::Widget * child = page->get_child();
		if (child)
		{
			return (Gtk::Widget*)child->get_user_data();
		}
		else
		{
			return 0;
		}
	}
	else
	{
		return 0;
	}
}

void application::on_set_grid ()
{
}
