// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2001 Liam Girdwood  


#include "config.h"
#include <libgnome/libgnome.h>
#include "application.hh"
#include <gtk--/list.h>
#include <gtk--/menu.h>
#include <gtk--/radiomenuitem.h>
#include <gtk--/radiobutton.h>
#include <gtk--/checkmenuitem.h>
#include <gtk--/menubar.h>
#include <libgnomeui/gnome-app.h>
#include <libgnomeui/gnome-app-helper.h>
#include <gdk/gdkkeysyms.h>
#include <libgnomeui/gnome-stock.h>
#include <gnome--/dock-item.h>
#include <gtk--/button.h>
#include <gtk--/spinbutton.h>
#include <gtk--/adjustment.h>
#include <gtk--/toolbar.h>
#include <gnome--/pixmap.h>
#include <gtk--/box.h>
#include <gtk--/label.h>
#include <gtk--/notebook.h>
#include <gnome--/dock.h>
#include <gnome--/dock-layout.h>
#include <gnome--/appbar.h>
#include <gnome--/canvas.h>
#include <gnome--/canvas-rect.h>
#include <gtk--/pixmap.h>
#include <gtk--/imageloader.h>
#include <gdk--/color.h>

#include "nova.hh"

application_glade::application_glade(
) : Gnome::App("nova", _("Nova I.O.E."))
{   

	Gnome::App *application = this;
	Gtk::Notebook *mdi_parent = manage(new class Gtk::Notebook());
	m_mdi = mdi_parent;
	Gnome::AppBar *appbar = manage(new class Gnome::AppBar(true, true, GNOME_PREFERENCES_NEVER));

	mdi_parent->set_name("mdi_parent");
	mdi_parent->set_border_width(2);
	mdi_parent->set_show_tabs(true);
	mdi_parent->set_tab_border(3);
	appbar->set_name("appbar");
	application->set_name("application");
	application->set_border_width(2);
	application->set_title(_("Nova Integrated Observational Environment"));

	install_toolbar();
	install_menu();
	application->set_statusbar (*appbar);
	application->set_contents (*mdi_parent);
	
	// add window destroy callback
	application->destroy.connect(SigC::slot(static_cast<class application*>(this), &application::on_exit_activate));
	application->set_usize(800,600);
	application->show_all();
	message("This version of Nova is a developers release.\n\nIt contains limited functionality, and is intended \nto expose the functionality of Nova together with the \nlook and feel of the user interface.\n\nFeedback is welcome. \n\nThe Nova Team. :)");  
}


void application_glade::install_toolbar ()
{
	// Pixmaps
	char file_name [256];
		
	get_pixmap_file("observatory.xpm", file_name);
	Gtk::Pixmap * observatory_pix = manage (new class Gtk::Pixmap(file_name));
	Gtk::Pixmap * observatory2_pix = manage (new class Gtk::Pixmap(file_name));
	
	get_pixmap_file("camera.xpm", file_name);
	Gtk::Pixmap * ccd_pix = manage (new class Gtk::Pixmap(file_name));
	Gtk::Pixmap * ccd2_pix = manage (new class Gtk::Pixmap(file_name));
	
	get_pixmap_file("telescope.xpm", file_name);
	Gtk::Pixmap * telescope_pix = manage (new class Gtk::Pixmap(file_name));
	
	get_pixmap_file("sphere.xpm", file_name);
	Gtk::Pixmap * sphere_pix = manage (new class Gtk::Pixmap (file_name));
	
	get_pixmap_file("cylinder.xpm", file_name);
	Gtk::Pixmap * cylinder_pix = manage (new class Gtk::Pixmap(file_name));
	
	get_pixmap_file("grid.xpm", file_name);
	Gtk::Pixmap * grid_pix = manage (new class Gtk::Pixmap(file_name));	

	get_pixmap_file("brighter.xpm", file_name);
	Gtk::Pixmap * brighter_pix = manage (new class Gtk::Pixmap(file_name));	

	get_pixmap_file("fainter.xpm", file_name);
	Gtk::Pixmap * dimmer_pix = manage (new class Gtk::Pixmap(file_name));	

	get_pixmap_file("zoom_in.xpm", file_name);
	Gtk::Pixmap * zoom_in_pix = manage (new class Gtk::Pixmap(file_name));	

	get_pixmap_file("zoom_out.xpm", file_name);
	Gtk::Pixmap * zoom_out_pix = manage (new class Gtk::Pixmap(file_name));	
	
	get_pixmap_file("find.xpm", file_name);
	Gtk::Pixmap * find_pix = manage (new class Gtk::Pixmap(file_name));	
	
	// Toolbar
	//
	Gtk::Toolbar * toolbar = manage (new class Gtk::Toolbar());
		
	// clock
	clock = new class Gtk::Clock(Gtk::Clock::Type(GTK_CLOCK_REALTIME));
	clock->set_name("clock");
	clock->set_format("%H:%M:%S");
	clock->set_seconds(0);
	clock->set_update_interval(1);
	clock->show();
	
	// radio groups
	Gtk::RadioButton_Helpers::Group proj_group;
	Gtk::RadioButton_Helpers::Group coord_group;
	

	// labels
	Gtk::Label * ra = manage (new class Gtk::Label("R/D"));
	Gtk::Label * alt = manage (new class Gtk::Label("A/A"));
	
	// legend
	legend = manage (new class Gnome::Canvas());
	legend->set_usize (100, 24);
	Gnome::CanvasGroup * root = legend->root();
	legend->set_scroll_region (0, 0, 100, 24);
	
	// clear legend background to black
	Gnome::CanvasRect * rect = new Gnome::CanvasRect(*root, 0, 0, 100, 24);
  	*rect << Gnome::CanvasHelpers::width_pixels(2) << Gnome::CanvasHelpers::fill_color("black");

	
	{
		using namespace Gtk::Toolbar_Helpers;
		toolbar->tools().push_back(RadioElem(proj_group, *sphere_pix, 
			slot(static_cast<class application*>(this), &application::on_set_spherical_projection), 
			"Use Spherical Projection", 0));
		toolbar->tools().push_back(RadioElem(proj_group, *cylinder_pix, 
			slot(static_cast<class application*>(this), &application::on_set_cylindrical_projection), 
			"Use Cylindrical Projection", 0));
		toolbar->tools().push_back(Space());
		toolbar->tools().push_back(ToggleElem(0,*grid_pix, 
			slot(static_cast<class application*>(this), &application::on_set_grid), 
			"Grid On/Off", 0));
		toolbar->tools().push_back(Space());
		toolbar->tools().push_back(RadioElem(coord_group, *ra, 
			slot(static_cast<class application*>(this), &application::on_set_ra_dec_coords), 
			"Use RA/Dec Coordinates", 0));
		toolbar->tools().push_back(RadioElem(coord_group, *alt, 
			slot(static_cast<class application*>(this), &application::on_set_alt_az_coords), 
			"Use Alt/Az Coordinates", 0));
		toolbar->tools().push_back(Space());
		toolbar->tools().push_back(ButtonElem(0,*brighter_pix, 
			slot(static_cast<class application*>(this), &application::on_set_mag_limit_brighter), 
			"Mag Limit Brighter", 0));
		toolbar->tools().push_back(ButtonElem(0,*dimmer_pix, 
			slot(static_cast<class application*>(this), &application::on_set_mag_limit_fainter), 
			"Mag Limit Fainter", 0));
		toolbar->tools().push_back(ButtonElem(0,*find_pix, 
			slot(static_cast<class application*>(this), &application::on_goto_search_activate), 
			"Find Object", 0));
		toolbar->tools().push_back(ButtonElem(0,*zoom_in_pix, 
			slot(static_cast<class application*>(this), &application::on_zoom_in_button_clicked), 
			"Zoom In", 0));
		toolbar->tools().push_back(ButtonElem(0,*zoom_out_pix, 
			slot(static_cast<class application*>(this), &application::on_zoom_out_button_clicked), 
			"Zoom Out", 0));
		toolbar->tools().push_back(Space());
		toolbar->tools().push_back(ButtonElem(0,*observatory_pix, 
			slot(static_cast<class application*>(this), &application::on_observatory_connect_activate), 
			"Connect to Observatory", 0));
		toolbar->tools().push_back(ButtonElem(0,*observatory2_pix, 
			slot(static_cast<class application*>(this), &application::on_observatory_disconnect_activate), 
			"Disconnect from Observatory", 0));
		toolbar->tools().push_back(ButtonElem(0,*ccd_pix, 
			slot(static_cast<class application*>(this), &application::on_execute_target_list_activate), 
			"Execute Target List", 0));
		toolbar->tools().push_back(ButtonElem(0,*ccd2_pix, 
			slot(static_cast<class application*>(this), &application::on_stop_target_list_activate), 
			"Abort Target List", 0));
		toolbar->tools().push_back(Space());
		toolbar->tools().push_back(Element(*legend, "Legend", 0));
		toolbar->tools().push_back(Space());
		toolbar->tools().push_back(Element(*clock, "Clock", 0)); 
	
		set_toolbar (*toolbar);
	}
}


void application_glade::install_menu ()
{
	Gtk::MenuBar *menubar = manage(new class Gtk::MenuBar());
	Gtk::MenuItem *file_new;
	Gtk::MenuItem *file_open;
	Gtk::MenuItem *save;
	Gtk::MenuItem *save_as;
	Gtk::MenuItem *print;
	Gtk::MenuItem *print_setup;
	Gtk::MenuItem *file_close;
	Gtk::MenuItem *exit;
	Gtk::MenuItem *edit_ephemeris;
	Gtk::MenuItem *edit_target_list;
	Gtk::MenuItem *edit_object;
	Gtk::RadioMenuItem *cairneyhill1;
	Gtk::MenuItem *tlistn_n2;
	Gtk::MenuItem *window_virtual_sky;
	Gtk::MenuItem *window_target_list;
	Gtk::MenuItem *separator1;
	Gtk::MenuItem *window_fits;
	Gtk::CheckMenuItem *eph1;
	Gtk::CheckMenuItem *eph2;
	Gtk::CheckMenuItem *eph3;
	Gtk::MenuItem *view_moon;
	Gtk::MenuItem *view_mercury;
	Gtk::MenuItem *view_venus;
	Gtk::MenuItem *mars;
	Gtk::MenuItem *view_jupiter;
	Gtk::MenuItem *view_saturn;
	Gtk::MenuItem *view_uranus;
	Gtk::MenuItem *view_neptune;
	Gtk::MenuItem *view_pluto;
	Gtk::MenuItem *separator2;
	Gtk::MenuItem *view_asteroids;
	Gtk::MenuItem *view_comets;
	Gtk::MenuItem *view_galaxies;
	Gtk::MenuItem *view_nebulae;
	Gtk::MenuItem *view_other;
	Gtk::MenuItem *view_solar_system;
	Gtk::MenuItem *view_deep_sky;
	Gtk::MenuItem *view_coordinates;
	Gtk::MenuItem *separator3;
	Gtk::MenuItem *view_search;
	Gtk::MenuItem *view_in_x_2;
	Gtk::MenuItem *view_in_5;
	Gtk::MenuItem *view_in_x_10;
	Gtk::MenuItem *view_in_select_fov;
	Gtk::MenuItem *view_out_x_0p5;
	Gtk::MenuItem *view_out_x_0p2;
	Gtk::MenuItem *x_view_out_0p1;
	Gtk::MenuItem *view_out_select_fov;
	Gtk::MenuItem *view_zoom_to_fit;
	Gtk::MenuItem *view_zoom_select;
	Gtk::MenuItem *view_zoom_in;
	Gtk::MenuItem *view_zoom_out;
	Gtk::MenuItem *settings_location;
	Gtk::MenuItem *settings_markers;
	Gtk::MenuItem *settings_near_sky;
	Gtk::MenuItem *settings_deep_sky;
	Gtk::MenuItem *view_epheremis;
	Gtk::MenuItem *view_virtual_object;
	Gtk::MenuItem *view_zoom;
	Gtk::MenuItem *separator4;
	Gtk::MenuItem *view_settings;
	Gtk::RadioMenuItem *dome_open;
	Gtk::RadioMenuItem *dome_close;
	Gtk::RadioMenuItem *projection_spherical;
	Gtk::RadioMenuItem *projection_cylindrical;
	Gtk::RadioMenuItem *coords_ra_dec;
	Gtk::RadioMenuItem *coords_alt_az;
	Gtk::MenuItem *goto_moon;
	Gtk::MenuItem *goto_mercury;
	Gtk::MenuItem *goto_venus;
	Gtk::MenuItem *goto_mars;
	Gtk::MenuItem *goto_jupiter;
	Gtk::MenuItem *goto_saturn;
	Gtk::MenuItem *goto_uranus;
	Gtk::MenuItem *goto_neptune;
	Gtk::MenuItem *goto_pluto;
	Gtk::MenuItem *separator6;
	Gtk::MenuItem *goto_asteroid;
	Gtk::MenuItem *goto_comet;
	Gtk::MenuItem *goto_galaxies;
	Gtk::MenuItem *goto_nebulae;
	Gtk::MenuItem *goto_other;
	Gtk::MenuItem *goto_near_sky;
	Gtk::MenuItem *goto_deep_sky;
	Gtk::MenuItem *separator7;
	Gtk::MenuItem *goto_position;
	Gtk::MenuItem *goto_virtual_sky_coordinates;
	Gtk::MenuItem *separator8;
	Gtk::MenuItem *goto_search;
	Gtk::MenuItem *telescope_focus;
	Gtk::MenuItem *telescope_goto;
	Gtk::MenuItem *telescope_park;
	Gtk::MenuItem *ccd_capture;
	Gtk::CheckMenuItem *ccd_live_view;
	Gtk::MenuItem *ccd_dark_frame;
	Gtk::MenuItem *execute_target_list;
	Gtk::MenuItem *stop_target_list;
	Gtk::MenuItem *separator5;
	Gtk::MenuItem *dome;
	Gtk::MenuItem *telescope;
	Gtk::MenuItem *ccd;
	Gtk::MenuItem *separator9;
	Gtk::MenuItem *tools_enhance_image;
	Gtk::MenuItem *options_database;
	Gtk::MenuItem *help_contents;
	Gtk::MenuItem *separator10;
	Gtk::MenuItem *separator11;	
	Gtk::MenuItem *separator12;
	Gtk::MenuItem *about;
	Gtk::MenuItem *file;
	Gtk::MenuItem *edit;
	Gtk::MenuItem *window;
	Gtk::MenuItem *view;
	Gtk::MenuItem *observatory_menu;
	Gtk::MenuItem *tools;
	Gtk::MenuItem *options;
	Gtk::MenuItem *help;
	Gtk::MenuItem *observatory_connect;
	Gtk::MenuItem *observatory_disconnect;
	{   
	
		static GnomeUIInfo file_menu_uiinfo[] = 
		{
	        	GNOMEUIINFO_MENU_NEW_ITEM(N_("_New..."), N_(""), 0, 0), 
			GNOMEUIINFO_MENU_OPEN_ITEM(0, 0), 
			GNOMEUIINFO_MENU_SAVE_ITEM(0, 0), 
			GNOMEUIINFO_MENU_SAVE_AS_ITEM(0, 0), 
			GNOMEUIINFO_MENU_PRINT_ITEM(0, 0), 
			GNOMEUIINFO_MENU_PRINT_SETUP_ITEM(0, 0),
			GNOMEUIINFO_MENU_CLOSE_ITEM(0,0), 
			GNOMEUIINFO_MENU_EXIT_ITEM(0, 0), 
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo edit_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Ephemeris"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Target List"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Object"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo cairneyhill1_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Cairneyhill"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo window_virtual_sky_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_RADIOITEMS, 0, 0,  cairneyhill1_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo window_target_list_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Telescope n"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo window_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_SUBTREE, N_("Virtual Sky"), 0,  window_virtual_sky_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Target List"), 0,  window_target_list_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_ITEM, N_("F.I.T.S"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo view_epheremis_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_TOGGLEITEM, N_("eph1"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_TOGGLEITEM, N_("eph2"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_TOGGLEITEM, N_("eph3"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		 
		static GnomeUIInfo view_solar_system_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("  Moon"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/moon.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Mercury"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/mercury.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Venus"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/venus.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Mars..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/mars.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Jupiter..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/jupiter.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Saturn..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/saturn.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Uranus..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/uranus.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Neptune..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/neptune.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Pluto..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/pluto.xpm",  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_ITEM, N_("  Asteroids..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/asteroids.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Comets..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/comet.xpm",  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo view_deep_sky_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("  Galaxies..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/galaxy.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Nebulae..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/nebula.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Other..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo view_virtual_object_menu_uiinfo[] = 
		{        
			{ GNOME_APP_UI_SUBTREE, N_("Solar System"), 0,  view_solar_system_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Deep Sky"), 0,  view_deep_sky_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Coordinates"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_ITEM, N_("Search..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo view_zoom_in_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("x 2"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("x 5"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("x 10"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Select F.O.V."), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo view_zoom_out_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("x 0.5"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("x 0.2"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("x 0.1"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Select F.O.V."), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo view_zoom_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Zoom to Fit"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Zoom Select"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Zoom In"), 0,  view_zoom_in_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Zoom Out"), 0,  view_zoom_out_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo sky_projection_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Spherical"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Cylindrical"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo projection_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_RADIOITEMS, 0, 0,  sky_projection_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};


		static GnomeUIInfo sky_coordinate_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Ra / Dec"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Alt / Az"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};

		static GnomeUIInfo coordinate_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_RADIOITEMS, 0, 0,  sky_coordinate_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};

		
		
		static GnomeUIInfo view_settings_menu_uiinfo[] = 
		{
			{ GNOME_APP_UI_SUBTREE, N_("Projection"), 0, projection_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Coordinates"), 0, coordinate_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR,
		        { GNOME_APP_UI_ITEM, N_("  Local"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/earth.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Markers"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/grid.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Near Sky"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/sun.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Deep Sky"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/galaxy.xpm",  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
				
		static GnomeUIInfo view_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_SUBTREE, N_("Epheremis"), 0,  view_epheremis_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Virtual Object"), 0,  view_virtual_object_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Zoom"), 0,  view_zoom_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_SUBTREE, N_("Settings"), 0,  view_settings_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo dome_open_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Open"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Close"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo dome_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_RADIOITEMS, 0, 0,  dome_open_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo goto_near_sky_menu_uiinfo[] = 
		{        
			{ GNOME_APP_UI_ITEM, N_("  Moon..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/moon.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Mercury"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/mercury.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Venus"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/venus.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Mars..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/mars.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Jupiter..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/jupiter.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Saturn..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/saturn.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Uranus..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/uranus.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Neptune..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/neptune.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Pluto..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/pluto.xpm",  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_ITEM, N_("  Asteroid..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/asteroids.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Comet.."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/comet.xpm",  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo goto_deep_sky_menu_uiinfo[] = 
		{        
			{ GNOME_APP_UI_ITEM, N_("  Galaxies"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/galaxy.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Nebulae..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/nebula.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Other..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo telescope_goto_menu_uiinfo[] = 
		{        
			{ GNOME_APP_UI_SUBTREE, N_("Solar System"), 0,  goto_near_sky_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Deep Sky"), 0,  goto_deep_sky_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_ITEM, N_("Coordinates"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Virtual Sky Coordinates"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_ITEM, N_("Search..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo telescope_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Focus"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Goto"), 0,  telescope_goto_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_JUMP_TO,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("Park"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo ccd_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("  Capture..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/camera.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_TOGGLEITEM, N_("  Live View"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Dark frame"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo observatory_menu_menu_uiinfo[] = 
		{        
			{ GNOME_APP_UI_ITEM, N_("  Execute Target List"), 0,  0, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXEC,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Stop Target List"), 0,  0, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_STOP,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_SUBTREE, N_("  Dome"), 0,  dome_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/observatory.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("  Telescope"), 0,  telescope_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/telescope.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("  CCD"), 0,  ccd_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/camera.xpm",  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			{ GNOME_APP_UI_ITEM, N_("  Connect"), 0,  0, 0, 0, GNOME_APP_PIXMAP_FILENAME, "nova/observatory.xpm",  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_ITEM, N_("  Disconnect"), 0,  0, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo tools_menu_uiinfo[] = 
		{        
			{ GNOME_APP_UI_ITEM, N_("Enhance Image..."), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo options_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Database Access"), 0,  0, 0, 0, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_OPEN,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo help_menu_uiinfo[] = 
		{
		        { GNOME_APP_UI_ITEM, N_("Contents"), 0,  0, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_SEPARATOR, 
			GNOMEUIINFO_MENU_ABOUT_ITEM(0, 0), 
			GNOMEUIINFO_END 
		};
		
		static GnomeUIInfo menubar_uiinfo[] = 
		{
		        { GNOME_APP_UI_SUBTREE, N_("File"), 0,  file_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Edit"), 0,  edit_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Window"), 0,  window_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("View"), 0,  view_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Observatory"), 0,  observatory_menu_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Tools"), 0,  tools_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Options"), 0,  options_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			{ GNOME_APP_UI_SUBTREE, N_("Help"), 0,  help_menu_uiinfo, 0, 0, GNOME_APP_PIXMAP_NONE, 0,  0, (GdkModifierType)0, 0 },
			GNOMEUIINFO_END 
		};
		
		gnome_app_fill_menu(GTK_MENU_SHELL(menubar->gtkobj()), menubar_uiinfo, NULL, true, 0);
		file_new = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[0].widget));
		file_open = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[1].widget));
		save = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[2].widget));
		save_as = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[3].widget));
		print = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[4].widget));
		print_setup = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[5].widget));
		file_close = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[6].widget));
		exit = Gtk::wrap(GTK_MENU_ITEM(file_menu_uiinfo[7].widget));
		edit_ephemeris = Gtk::wrap(GTK_MENU_ITEM(edit_menu_uiinfo[0].widget));
		edit_target_list = Gtk::wrap(GTK_MENU_ITEM(edit_menu_uiinfo[1].widget));
		edit_object = Gtk::wrap(GTK_MENU_ITEM(edit_menu_uiinfo[2].widget));
		cairneyhill1 = Gtk::wrap(GTK_RADIO_MENU_ITEM(cairneyhill1_uiinfo[0].widget));
		tlistn_n2 = Gtk::wrap(GTK_MENU_ITEM(window_target_list_menu_uiinfo[0].widget));
		separator1 = Gtk::wrap(GTK_MENU_ITEM(window_menu_uiinfo[2].widget));
		window_fits = Gtk::wrap(GTK_MENU_ITEM(window_menu_uiinfo[3].widget));
		eph1 = Gtk::wrap(GTK_CHECK_MENU_ITEM(view_epheremis_menu_uiinfo[0].widget));
		eph2 = Gtk::wrap(GTK_CHECK_MENU_ITEM(view_epheremis_menu_uiinfo[1].widget));
		eph3 = Gtk::wrap(GTK_CHECK_MENU_ITEM(view_epheremis_menu_uiinfo[2].widget));
		view_moon = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[0].widget));
		view_mercury = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[1].widget));
		view_venus = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[2].widget));
		mars = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[3].widget));
		view_jupiter = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[4].widget));
		view_saturn = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[5].widget));
		view_uranus = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[6].widget));
		view_neptune = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[7].widget));
		view_pluto = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[8].widget));
		separator2 = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[9].widget));
		view_asteroids = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[10].widget));
		view_comets = Gtk::wrap(GTK_MENU_ITEM(view_solar_system_menu_uiinfo[11].widget));
		view_galaxies = Gtk::wrap(GTK_MENU_ITEM(view_deep_sky_menu_uiinfo[0].widget));
		view_nebulae = Gtk::wrap(GTK_MENU_ITEM(view_deep_sky_menu_uiinfo[1].widget));
		view_other = Gtk::wrap(GTK_MENU_ITEM(view_deep_sky_menu_uiinfo[2].widget));
		view_coordinates = Gtk::wrap(GTK_MENU_ITEM(view_virtual_object_menu_uiinfo[2].widget));
		separator3 = Gtk::wrap(GTK_MENU_ITEM(view_virtual_object_menu_uiinfo[3].widget));
		view_search = Gtk::wrap(GTK_MENU_ITEM(view_virtual_object_menu_uiinfo[4].widget));
		view_in_x_2 = Gtk::wrap(GTK_MENU_ITEM(view_zoom_in_menu_uiinfo[0].widget));
		view_in_5 = Gtk::wrap(GTK_MENU_ITEM(view_zoom_in_menu_uiinfo[1].widget));
		view_in_x_10 = Gtk::wrap(GTK_MENU_ITEM(view_zoom_in_menu_uiinfo[2].widget));
		view_in_select_fov = Gtk::wrap(GTK_MENU_ITEM(view_zoom_in_menu_uiinfo[3].widget));
		view_out_x_0p5 = Gtk::wrap(GTK_MENU_ITEM(view_zoom_out_menu_uiinfo[0].widget));
		view_out_x_0p2 = Gtk::wrap(GTK_MENU_ITEM(view_zoom_out_menu_uiinfo[1].widget));
		x_view_out_0p1 = Gtk::wrap(GTK_MENU_ITEM(view_zoom_out_menu_uiinfo[2].widget));
		view_out_select_fov = Gtk::wrap(GTK_MENU_ITEM(view_zoom_out_menu_uiinfo[3].widget));
		view_zoom_to_fit = Gtk::wrap(GTK_MENU_ITEM(view_zoom_menu_uiinfo[0].widget));
		view_zoom_select = Gtk::wrap(GTK_MENU_ITEM(view_zoom_menu_uiinfo[1].widget));
		projection_spherical = Gtk::wrap(GTK_RADIO_MENU_ITEM(sky_projection_uiinfo[0].widget));
		projection_cylindrical = Gtk::wrap(GTK_RADIO_MENU_ITEM(sky_projection_uiinfo[1].widget));
		coords_ra_dec = Gtk::wrap(GTK_RADIO_MENU_ITEM(sky_coordinate_uiinfo[0].widget));
		coords_alt_az = Gtk::wrap(GTK_RADIO_MENU_ITEM(sky_coordinate_uiinfo[1].widget));
		separator11 = Gtk::wrap(GTK_MENU_ITEM(view_settings_menu_uiinfo[2].widget));
		settings_location = Gtk::wrap(GTK_MENU_ITEM(view_settings_menu_uiinfo[3].widget));
		settings_markers = Gtk::wrap(GTK_MENU_ITEM(view_settings_menu_uiinfo[4].widget));
		settings_near_sky = Gtk::wrap(GTK_MENU_ITEM(view_settings_menu_uiinfo[5].widget));
		settings_deep_sky = Gtk::wrap(GTK_MENU_ITEM(view_settings_menu_uiinfo[6].widget));
		separator4 = Gtk::wrap(GTK_MENU_ITEM(view_menu_uiinfo[3].widget));
		dome_open = Gtk::wrap(GTK_RADIO_MENU_ITEM(dome_open_uiinfo[0].widget));
		dome_close = Gtk::wrap(GTK_RADIO_MENU_ITEM(dome_open_uiinfo[1].widget));
		goto_moon = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[0].widget));
		goto_mercury = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[1].widget));
		goto_venus = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[2].widget));
		goto_mars = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[3].widget));
		goto_jupiter = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[4].widget));
		goto_saturn = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[5].widget));
		goto_uranus = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[6].widget));
		goto_neptune = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[7].widget));
		goto_pluto = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[8].widget));
		separator6 = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[9].widget));
		goto_asteroid = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[10].widget));
		goto_comet = Gtk::wrap(GTK_MENU_ITEM(goto_near_sky_menu_uiinfo[11].widget));
		goto_galaxies = Gtk::wrap(GTK_MENU_ITEM(goto_deep_sky_menu_uiinfo[0].widget));
		goto_nebulae = Gtk::wrap(GTK_MENU_ITEM(goto_deep_sky_menu_uiinfo[1].widget));
		goto_other = Gtk::wrap(GTK_MENU_ITEM(goto_deep_sky_menu_uiinfo[2].widget));
		separator7 = Gtk::wrap(GTK_MENU_ITEM(telescope_goto_menu_uiinfo[2].widget));
		goto_position = Gtk::wrap(GTK_MENU_ITEM(telescope_goto_menu_uiinfo[3].widget));
		goto_virtual_sky_coordinates = Gtk::wrap(GTK_MENU_ITEM(telescope_goto_menu_uiinfo[4].widget));
		separator8 = Gtk::wrap(GTK_MENU_ITEM(telescope_goto_menu_uiinfo[5].widget));
		goto_search = Gtk::wrap(GTK_MENU_ITEM(telescope_goto_menu_uiinfo[6].widget));
		telescope_focus = Gtk::wrap(GTK_MENU_ITEM(telescope_menu_uiinfo[0].widget));
		telescope_park = Gtk::wrap(GTK_MENU_ITEM(telescope_menu_uiinfo[2].widget));
		ccd_capture = Gtk::wrap(GTK_MENU_ITEM(ccd_menu_uiinfo[0].widget));
		ccd_live_view = Gtk::wrap(GTK_CHECK_MENU_ITEM(ccd_menu_uiinfo[1].widget));
		ccd_dark_frame = Gtk::wrap(GTK_MENU_ITEM(ccd_menu_uiinfo[2].widget));
		execute_target_list = Gtk::wrap(GTK_MENU_ITEM(observatory_menu_menu_uiinfo[0].widget));
		stop_target_list = Gtk::wrap(GTK_MENU_ITEM(observatory_menu_menu_uiinfo[1].widget));
		separator5 = Gtk::wrap(GTK_MENU_ITEM(observatory_menu_menu_uiinfo[2].widget));
		separator9 = Gtk::wrap(GTK_MENU_ITEM(observatory_menu_menu_uiinfo[6].widget));
		tools_enhance_image = Gtk::wrap(GTK_MENU_ITEM(tools_menu_uiinfo[0].widget));
		options_database = Gtk::wrap(GTK_MENU_ITEM(options_menu_uiinfo[0].widget));
		help_contents = Gtk::wrap(GTK_MENU_ITEM(help_menu_uiinfo[0].widget));
		separator10 = Gtk::wrap(GTK_MENU_ITEM(help_menu_uiinfo[1].widget));
		about = Gtk::wrap(GTK_MENU_ITEM(help_menu_uiinfo[2].widget));
		observatory_connect = Gtk::wrap(GTK_MENU_ITEM(observatory_menu_menu_uiinfo[7].widget));
		observatory_disconnect = Gtk::wrap(GTK_MENU_ITEM(observatory_menu_menu_uiinfo[8].widget));
	}

	menubar->set_name("menubar");
	menubar->set_border_width(2);

	menubar->show();

	file_new->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_file_new_activate));
	file_open->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_file_open_activate));
	save->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_save_activate));
	save_as->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_save_as_activate));
	print->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_print_activate));
	print_setup->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_print_setup_activate));
	file_close->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_file_close_activate));
	exit->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_exit_activate));
	edit_ephemeris->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_edit_ephemeris_activate));
	edit_target_list->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_edit_target_list_activate));
	edit_object->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_edit_object_activate));
	cairneyhill1->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_cairneyhill1_activate));
	tlistn_n2->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_tlist_n2_activate));
	window_fits->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_window_fits_activate));
	eph1->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_eph1_activate));
	eph2->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_eph2_activate));
	eph3->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_eph3_activate));
	view_moon->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_moon_activate));
	view_mercury->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_mercury_activate));
	view_venus->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_venus_activate));
	mars->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_mars_activate));
	view_jupiter->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_jupiter_activate));
	view_saturn->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_saturn_activate));
	view_uranus->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_uranus_activate));
	view_neptune->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_neptune_activate));
	view_pluto->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_pluto_activate));
	view_asteroids->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_asteroids_activate));
	view_comets->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_comets_activate));
	view_galaxies->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_galaxies_activate));
	view_nebulae->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_nebulae_activate));
	view_other->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_other_activate));
	view_coordinates->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_coordinates_activate));
	view_search->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_search_activate));
	view_zoom_to_fit->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_zoom_to_fit_activate));
	view_zoom_select->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_zoom_select_activate));
	view_in_x_2->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_in_x_2_activate));
	view_in_5->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_in_x_5_activate));
	view_in_x_10->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_in_x_10_activate));
	view_in_select_fov->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_in_select_fov_activate));
	view_out_x_0p5->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_out_x_0p5_activate));
	view_out_x_0p2->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_ot_0p2_activate));
	x_view_out_0p1->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_out_0p1x_activate));
	view_out_select_fov->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_out_select_fov_activate));
	settings_location->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_settings_location_activate));
	settings_markers->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_view_markers_activate));
	settings_near_sky->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_settings_near_sky));
	settings_deep_sky->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_settings_deep_sky_activate));
	execute_target_list->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_execute_target_list_activate));
	stop_target_list->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_stop_target_list_activate));
	dome_open->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_dome_open_activate));
	dome_close->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_dome_close_activate));
	telescope_focus->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_telescope_focus_activate));
	goto_moon->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_moon_activate));
	goto_mercury->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_mercury_activate));
	goto_venus->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_venus_activate));
	goto_mars->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_mars_activate));
	goto_jupiter->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_jupiter_activate));
	goto_saturn->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_saturn_activate));
	goto_uranus->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_uranus_activate));
	goto_neptune->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_neptune_activate));
	goto_pluto->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_pluto_activate));
	goto_asteroid->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_asteroid_activate));
	goto_comet->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_comet_activate));
	goto_galaxies->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_galaxies_activate));
	goto_nebulae->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_nebulae_activate));
	goto_other->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_other_activate));
	goto_position->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_position_activate));
	goto_virtual_sky_coordinates->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_virtual_sky_coordinates_activate));
	goto_search->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_goto_search_activate));
	telescope_park->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_telescope_park_activate));
	ccd_capture->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_ccd_capture_activate));
	ccd_live_view->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_ccd_live_view_activate));
	ccd_dark_frame->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_ccd_dark_frame_activate));
	tools_enhance_image->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_tools_enhance_image_activate));
	options_database->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_options_database_activate));
	help_contents->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_help_contents_activate));
	about->activate.connect(SigC::slot(static_cast<class application*>(this), &application::on_about_activate));

	set_menus (*menubar);
}

application_glade::~application_glade()
{   delete clock;
}
