// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2001 Liam Girdwood


#ifndef _BSC_OBJECT_HH
#  define _BSC_OBJECT_HH
#include "astro_object.hh"
#include <glib.h>

class bsc_object : public astro_object
{   
	public:
		struct bsc_data
		{
			gshort hr_number;		// Harvard Revised Number = Bright Star Number
			gchar name[10];			// Name, generally Bayer and/or Flamsteed name
			gchar DM[11];			// Durchmusterung Identification
			gint HD;			// Henry Draper Catalog Number
			gint SAO;			// SAO Catalog Number
			gshort FK5;			// FK5 star Number
			gboolean IR;			// if infrared source
			gchar ADS[5];        		// Aitken's float Star Catalog (ADS) designation
			gchar ADScomp[2];    		// ADS number components
			gchar VarID[9];      		// Variable star identification
			gfloat GLON;       		// Galactic longitude
			gfloat GLAT;      		// Galactic latitude
			gchar u_Vmag; 			// Uncertainty flag on V
			gfloat B_V; 			// B-V color in the UBV system
			gchar u_B_V; 			// Uncertainty flag on B-V
			gfloat U_B;			// U-B color in the UBV system
			gchar u_U_B;			// Uncertainty flag on U-B
			gfloat R_I;			// R-I   in system specified by n_R-I
			gchar n_R_I;			// Code for R-I system (Cousin, Eggen)
			gchar SpType[20];		// Spectral type
			gchar n_SpType;			// Spectral type code
			gfloat pmRA;			// Annual proper motion in RA J2000, FK5 system
			gfloat pmDE;			// Annual proper motion in Dec J2000, FK5 system
			gboolean n_Parallax; 		// indicates a dynamical parallax, otherwise a trigonometric parallax
			gfloat Parallax; 		// Trigonometric parallax (unless n_Parallax)
			gshort RadVel;			// Heliocentric Radial Velocity
			gchar l_RotVel[2];   		// Rotational velocity limit characters
			gshort RotVel; 			// Rotational velocity, v sin i
			gchar u_RotVel; 		// uncertainty and variability flag on RotVel
			gfloat Dmag; 			// Magnitude difference of float, or brightest multiple
			gfloat Sep;        		// Separation of components in Dmag if occultation binary.
			gchar MultID[4];     		// Identifications of components in Dmag
			guchar MultCnt;			// Number of components assigned to a multiple
			gchar * Notes;			// ptr to notes if any
		} bsc;
		
		bsc_object();
		~bsc_object();
		
		int get_size();
};
#endif

