// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2001 Liam Girdwood

#ifndef _OBJECT_CACHE_H
#define _OBJECT_CACHE_H

#include "astro_object.hh"

#define SECT_RA		24 			// ra segments
#define SECT_DEC	18 			// dec segments
#define SECT_TYPE	12 			// number of object types
#define CACHE_SIZE	1024 * 1024 * 10 	// 10Mb default cache size

// This is a 3D (x,y,z) RAM cache (array) of astro objects used to improve performance
// The (x,y) dimensions represent the sector (ra,dec) in sky wich the object belongs.
// The z dimension represnts the type (catalouge) the object comes from.
// Each object type in sector is stored as a linked list. 
// Nova will only have 1 object cache therefore this is a singleton 

class object_cache 
{
	public:
		static object_cache * instance (); 	// creation
		static void release ();			// destruction
		
		astro_object * get_sector_head (int ra, int dec, int type);
		astro_object * get_sector_tail (int ra, int dec, int type);
		int flush_sector (int ra, int dec, int type);
		int get_sector_size (int ra, int dec, int type);
		int add_object (astro_object * object);
		int get_cache_size ();
		void set_cache_size (int bytes);
		int get_cache_free ();
	
	private:
		astro_object * m_sector_head[SECT_RA][SECT_DEC][SECT_TYPE];
		astro_object * m_sector_tail[SECT_RA][SECT_DEC][SECT_TYPE];
		int m_sector_size[SECT_RA][SECT_DEC][SECT_TYPE];
		int m_sector_type[SECT_RA][SECT_DEC][SECT_TYPE];
		int m_max_cache_size;
		int m_cache_size;
		static object_cache * m_cache;
		int delete_list (astro_object * head);
		
		// private as object is a singleton
		object_cache();
		~object_cache();
};

#endif
		
