// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2001 Liam Girdwood

#include <string>
#include "virtual_sky_info.hh"

virtual_sky_info::virtual_sky_info ()
{
	m_finished = false;
	m_page = 0;

	// markers / display settings
	m_ra_dec_coords = true;
	m_cylinder_projection = true;
	m_grid = false;
	m_grid_separation.ra.hours = 0;
	m_grid_separation.ra.minutes = 0;
	m_grid_separation.ra.seconds = 0;
	m_grid_separation.dec.degrees = 0;
	m_grid_separation.dec.minutes = 0;
	m_grid_separation.dec.seconds = 0;
	m_view_symbols = true;
	m_view_colours = true;
	m_view_horizon = false;
	m_view_equator = false;
	m_view_ecliptic = false;
	m_view_galactic = false;
	m_view_const_boundary = false;
	m_view_const_figure = true;
	m_view_const_name = false;
	m_label_stars = false;
	m_label_ngc = false;
	m_label_solar = false;
	m_label_field = false;

	// near sky settings
	m_show_inner_planets = false;
	m_show_inner_sun = false;
	m_show_inner_phase = false;
	m_show_high_precision = false;
	m_show_outer_planets = false;
	m_show_outer_phase = false;
	m_show_outer_satellites = false;
	m_show_outer_high_precision = false;
	m_show_outer_features = false;
	m_show_outer_rings = false;

	// asteroids
	m_show_asteroids = false;
	m_show_all_asteroids = false;
	m_show_asteroid_min_orbit = 0;
	m_show_asteroid_max_orbit = 0;
	m_show_asteroid_mag_limit = 0;
	m_show_asteroid_position_range = 0;
	m_show_asteroid_position.ra.hours = 0;
	m_show_asteroid_position.ra.minutes = 0;
	m_show_asteroid_position.ra.seconds = 0;
	m_show_asteroid_position.dec.degrees = 0;
	m_show_asteroid_position.dec.minutes = 0;
	m_show_asteroid_position.dec.seconds = 0;


	// comets
	m_show_comets = false;
	m_show_all_comets = false;
	m_show_comet_min_orbit = 0;
	m_show_comet_max_orbit = 0;
	m_show_comet_mag_limit = 0;
	m_show_comet_position_range = 0;
	m_show_comet_position.ra.hours = 0;
	m_show_comet_position.ra.minutes = 0;
	m_show_comet_position.ra.seconds = 0;
	m_show_comet_position.dec.degrees = 0;
	m_show_comet_position.dec.minutes = 0;
	m_show_comet_position.dec.seconds = 0;


	// Earth - Moon
	m_show_iss = false;
	m_show_iss_trail = false;
	m_show_artificial_sats = false;
	m_show_artificial_sats_trail = false;
	m_show_moon = false;
	m_show_moon_phase = false;
	m_show_moon_detail = false;
	m_show_moon_detail = false;
	m_show_moon_high_precision = false;
	m_show_moon_outline = false;

}

virtual_sky_info::~virtual_sky_info ()
{
}

string virtual_sky_info::get_name ()
{
	return m_name;
}

void virtual_sky_info::set_name (string name)
{
	m_name = name; 
}

void virtual_sky_info::set_finished (bool finished)
{
	m_finished = finished;
}

bool virtual_sky_info::is_finished ()
{
	if (m_finished)
		return true;
	else
		return false;
}

void virtual_sky_info::set_page (Gtk::Widget * page)
{
	m_page = page;
}

Gtk::Widget * virtual_sky_info::get_page ()
{
	return (m_page);
}

void virtual_sky_info::set_mag_limit_brighter ()
{
}

void virtual_sky_info::set_mag_limit_fainter ()
{
}

void virtual_sky_info::set_cylindrical_projection ()
{
}

void virtual_sky_info::set_spherical_projection ()
{
}

void virtual_sky_info::set_ra_dec_coords()
{
}

void virtual_sky_info::set_alt_az_coords ()
{
}

// page zoom
void virtual_sky_info::zoom_in (double val)
{
	m_pixels_per_unit -= val;

}

void virtual_sky_info::zoom_out (double val)
{
	m_pixels_per_unit -= val;
}

// goto and field of view
void virtual_sky_info::goto_coords (double RA, double dec)
{
	m_centre_x_position = RA;
	m_centre_y_position = dec;
}

void virtual_sky_info::set_fov (double size)
{
	m_fov_size = size;
}

// page move
void virtual_sky_info::move_x (double val)
{
	m_centre_x_position += val;
}

void virtual_sky_info::move_y (double val)
{
	m_centre_y_position += val;
}

// get/set vsky druid settings

string virtual_sky_info::get_location ()
{
	return (m_location);
}

void virtual_sky_info::set_location (string location)
{
	m_location = location;
}

ln_long_lat_position * virtual_sky_info::get_position()
{
	return &m_position;
}

void virtual_sky_info::set_position (ln_long_lat_position * position)
{
	memcpy (&m_position, position, sizeof(m_position)); 
}

float virtual_sky_info::get_elevation ()
{
	return m_elevation;
}

void virtual_sky_info::set_elevation (float elevation)
{
	m_elevation = elevation;
}

float virtual_sky_info::get_temperature ()
{
	return m_temperature;
}

void virtual_sky_info::set_temperature (float temperature)
{
	m_temperature = temperature;
}

float virtual_sky_info::get_pressure ()
{
	return m_pressure;
}

void virtual_sky_info::set_pressure (float pressure)
{
	m_pressure = pressure;
}

string virtual_sky_info::get_timezone ()
{
	return m_timezone;
}

void virtual_sky_info::set_timezone(string timezone)
{
	m_timezone = timezone;
}

float virtual_sky_info::get_epoch ()
{
	return m_epoch;
}

void virtual_sky_info::set_epoch (float epoch)
{
	m_epoch = epoch;
}


ln_date * virtual_sky_info::get_date ()
{
	return &m_date;
}

void virtual_sky_info::set_date (ln_date * date)
{
	memcpy (&m_date, date, sizeof(m_date));
}


