// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2001 Liam Girdwood

#ifndef _VIRTUAL_SKY_INFO_H
#define _VIRTUAL_SKY_INFO_H

#include <string>
#include <gtk--/widget.h>
#include <libnova.h>

class virtual_sky_info
{
	public:
		virtual_sky_info();
		~virtual_sky_info();

		// points to vsky page		
		Gtk::Widget * get_page ();
		void set_page (Gtk::Widget * page);
		
		// druid status
		bool is_finished ();
		void set_finished (bool finished);
			
		// set view setings
		void set_mag_limit_brighter ();
		void set_mag_limit_fainter ();
		void set_cylindrical_projection ();
		void set_spherical_projection ();
		void set_ra_dec_coords();
		void set_alt_az_coords ();
		void zoom_in (double val);
		void zoom_out (double val);
		void goto_coords (double RA, double DEC);
		void set_fov (double size);
		void move_x (double val);
		void move_y (double val);
		
		// view settings data members 
		bool m_update_sky;
		double m_pixels_per_unit;
		double m_centre_x_position;
		double m_centre_y_position;
		double m_fov_size;
		
		// get/set vsky druid settings
		string get_name();
		void set_name (string name);
		string get_location ();
		void set_location (string location);
		ln_long_lat_position * get_position();
		void set_position (ln_long_lat_position * position);
		float get_elevation ();
		void set_elevation (float elevation);
		float get_temperature ();
		void set_temperature (float temperature);
		float get_pressure ();
		void set_pressure (float pressure);
		string get_timezone ();
		void set_timezone(string timezone);
		float get_epoch ();
		void set_epoch (float epoch);
		ln_date * get_date ();
		void set_date (ln_date * date);
		
		// get/set markers / display settings
		bool is_ra_dec_coords ();
		void set_ra_dec_coords (bool ra_dec);
		bool is_cylinder_projection ();
		void set_cylinder_projection (bool cylinder);
		bool is_grid_displayed ();
		void display_grid (bool display);
		ln_equ_position * get_grid_separation();
		void set_grid_separation (ln_equ_position * separation);
		bool is_symbols_displayed ();
		void display_symbols (bool display);
		bool is_colours_displayed ();
		void display_colours (bool display);
		bool is_horizon_displayed ();
		void display_horizon (bool display);
		bool is_equator_displayed ();
		void display_equator (bool display);
		bool is_ecliptic_displayed ();
		void display_ecliptic (bool display);
		bool is_galactic_displayed ();
		void display_galactic (bool display);
		bool is_const_boundary_displayed ();
		void display_const_boundary (bool display);
		bool is_const_figure_displayed ();
		void display_const_figure (bool display);
		bool is_const_name_displayed ();
		void display_const_name (bool display);
		bool is_label_stars_displayed ();
		void display_label_stars (bool display);
		bool is_label_ngc_displayed ();
		void display_label_ngc (bool display);
		bool is_label_solar_displayed ();
		void display_label_solar (bool display);
		bool is_label_field_displayed ();
		void display_label_field (bool display);


		
	private:
		// sky data members
		string m_name;
		string m_location;
		ln_long_lat_position m_position;
		float m_elevation;
		float m_temperature;
		float m_pressure;
		string m_timezone;
		float m_epoch;
		ln_date m_date;
		ln_date m_utc_date;
		
		// markers / display settings
		bool m_ra_dec_coords;
		bool m_cylinder_projection;
		bool m_grid;
		ln_equ_position m_grid_separation;
		bool m_view_symbols;
		bool m_view_colours;
		bool m_view_horizon;
		bool m_view_equator;
		bool m_view_ecliptic;
		bool m_view_galactic;
		bool m_view_const_boundary;
		bool m_view_const_figure;
		bool m_view_const_name;
		bool m_label_stars;
		bool m_label_ngc;
		bool m_label_solar;
		bool m_label_field;
		
		// near sky settings
		bool m_show_inner_planets;
		bool m_show_inner_sun;
		bool m_show_inner_phase;
		bool m_show_high_precision;
		bool m_show_outer_planets;
		bool m_show_outer_phase;
		bool m_show_outer_satellites;
		bool m_show_outer_high_precision;
		bool m_show_outer_features;
		bool m_show_outer_rings;
		
		// asteroids
		bool m_show_asteroids;
		bool m_show_all_asteroids;
		float m_show_asteroid_min_orbit;
		float m_show_asteroid_max_orbit;
		float m_show_asteroid_mag_limit;
		float m_show_asteroid_position_range;
		ln_equ_position m_show_asteroid_position;
		
		// comets
		bool m_show_comets;
		bool m_show_all_comets;
		float m_show_comet_min_orbit;
		float m_show_comet_max_orbit;
		float m_show_comet_mag_limit;
		float m_show_comet_position_range;
		ln_equ_position m_show_comet_position;
		
		// Earth - Moon
		bool m_show_iss;
		bool m_show_iss_trail;
		bool m_show_artificial_sats;
		bool m_show_artificial_sats_trail;
		bool m_show_moon;
		bool m_show_moon_phase;
		bool m_show_moon_detail;
		bool m_show_moon_high_precision;
		bool m_show_moon_outline;

		// app
		bool m_finished;
		Gtk::Widget * m_page;
		
};

#endif
		
		
