// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. 

// Copyright 2001 Liam Girdwood  

#include "virtual_sky_page.hh"
#include "bsc_object.hh"
#include "object_cache.hh"
#include "virtual_sky_info.hh"
#include <gnome--/canvas-ellipse.h>
#include <gnome--/canvas-rect.h>
#include <gnome--/canvas.h>
#include <gnome--/canvas-property.h>
#include <gnome--/canvas-item.h>
#include <gnome--/canvas-text.h>

#include "config.h"
#include "virtual_sky_page.hh"
#include <iostream>

gint virtual_sky_page::on_canvas_button_press_event(GdkEventButton *ev)
{   return 0;
}

gint virtual_sky_page::on_canvas_button_release_event(GdkEventButton *ev)
{   return 0;
}

void virtual_sky_page::set_vsky_info (virtual_sky_info * info)
{
	m_info = info;
}

virtual_sky_info * virtual_sky_page::get_vsky_info (void)
{
	return (m_info);
}


virtual_sky_page::virtual_sky_page ()
{
	m_xmax = 2000;
	m_ymax = 1000;
	m_xmin = -1000;
	m_ymin = -2000;
	m_pixels = 1.0;
	
	m_object_cache = object_cache::instance();
	m_root = m_canvas->root();
	m_canvas->set_scroll_region (m_xmin, m_ymin, m_xmax, m_ymax);
	
	update_page_standard (ASTRO_BSC);
}

virtual_sky_page::~virtual_sky_page ()
{
	object_cache::release();
}

int virtual_sky_page::update_page_standard (int object_type)
{
	Gnome::CanvasRect *m_rect;
	astro_object * head = 0;
	astro_object * next;
	int ra, dec;

	// clear background to black
	m_rect = new Gnome::CanvasRect(*m_root, m_xmin, m_ymin, m_xmax, m_ymax);
  	*m_rect << Gnome::CanvasHelpers::width_pixels(2) << Gnome::CanvasHelpers::fill_color("black");

	// get name objects
	for (ra = 0; ra < 24; ra ++)
	{
		for (dec = 0; dec < 18; dec ++)
		{
			next = head = m_object_cache->get_sector_head (ra, dec, object_type);
			if (head)
			{
				switch(head->obj_type)
				{
					case ASTRO_BSC:
					{
					
						add_bsc_objects_to_page (next);
					}
					break;
				}
			}
		}
	}
	return(1);
}

int virtual_sky_page::add_bsc_objects_to_page (astro_object * object)
{
	Gnome::CanvasEllipse *m_ellipse;
	Gnome::CanvasText *m_text;
	double ra, dec, mag, radius;
	int count = 0;
	int object_class = 0;
	
	// add complete list
	while (object->tail)
	{
		do // dont use goto
		{
			// all objects have this
			ra = object->astro.RA;
			dec = object->astro.DEC;
			mag = object->astro.Vmag;
			
			// check if object is bright enough to be displayed
		//	if (mag > m_mag_limit)
		//		break;

			// calc canvas coords
			ra = m_xmax - (ra * ((m_xmax - m_xmin) / 24));
			dec = dec + 90;
			dec = dec * ((m_ymax - m_ymin) / 180);
			dec = m_ymax - dec;
			radius = get_object_size(mag);

			// get object class i.e. variable, etc
			object_class = 0;//object->get_class();
			switch (object_class)
			{
				case 0:
				{			
					m_ellipse = new Gnome::CanvasEllipse(*m_root, ra, dec, ra + radius, dec + radius);
					m_ellipse->set_user_data ((gpointer)object);
					*m_ellipse << Gnome::CanvasHelpers::fill_color("white");
				}
				break;
			//	case VARIABLE_STAR:
			//	{			
			//		m_ellipse = new Gnome::CanvasEllipse(*m_root, ra, dec, ra + radius, dec + radius);
			//		m_ellipse->set_user_data ((gpointer)object);
			//		*m_ellipse << Gnome::CanvasHelpers::fill_color("white");
			//	//	m_line = new Gnome::CanvasLine
			//	}
			//	break;
			}
			
			// should object name be_displayed
			if (mag < 4)//m_text_mag)
			{
				// text
			//	m_text = new Gnome::CanvasText(*m_root, ra + (radius/2) + 20, dec, ((bsc_object*)object)->get_object_name());
			//	*m_text << Gnome::CanvasHelpers::font("-Adobe-Helvetica-Medium-R-Normal--*-100-*-*-*-*-*-*")
			//	<< Gnome::CanvasHelpers::fill_color("blue"); //Changes the color of the text.
			}
		}
		while (0);
			
		// next object 
		object = object->tail;
		count ++;
	}
	return (count);
}

Gnome::Canvas * virtual_sky_page::get_canvas ()
{
	return (m_canvas);
}

double virtual_sky_page::get_pixels_per_unit ()
{
	return (m_pixels);
}

void virtual_sky_page::set_pixels_per_unit (double r)
{
	m_pixels = r;
}


/* very rough at the moment */
double virtual_sky_page::get_object_size (double mag)
{
	double size;
	int i_mag = (int)mag;
	
	// categorise into groups
	switch (i_mag)
	{
		case -2:
		 return 12;
		case -1:
		 return 10;
		case 0:
		 return 8;
		case 1:
		 return 6;
		case 2:
		 return 4;
		case 3:
		 return 2;
		case 4:
		 return 1;
		case 5:
		 return 0.5;
		case 6:
		 return 0.25;
		default:
			return 0;
	}
	return 0;
}


void virtual_sky_page::update_grid (Gnome::Canvas * root)
{
	// The grid is made up of several layers that get brighter as the
	// fov decreases (zoom in) and dimmer as fov increases.
	// Each grid layer has it's own canvas group. The grid can have
	// a variable number of layers, depending on the fov.
	// On creation 5 layers are drawn and 1 is visible.
}



